@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars '$VERSION';
 
-$VERSION = 0.7;
+$VERSION = '0.8';
 
 use constant SQL1992 => 0x01;
 use constant SQL1999 => 0x02;
@@ -367,7 +367,7 @@ use constant SQL2003 => 0x04;
     );
 
     sub is_reserved {
-        return $WORDS{ uc pop } || 0;
+        return $WORDS{ uc(pop || '') } || 0;
     }
 
     sub is_reserved_by_sql1992 {
